{
  lib,
  pkgs,
  ...
}: let
  borderRadius = 8;
  borderSize = 2;
  # TODO: font
  # TODO: status bar
in {
  imports = [
    ./waybar.nix
  ];

  catppuccin = {
    flavor = "mocha";
    accent = "lavender";

    hyprland.enable = true;
    rofi.enable = true;
    kitty.enable = true;
    mako.enable = true;
    waybar.enable = true;
    helix.enable = true;
    zsh-syntax-highlighting.enable = true;
    cursors.enable = true;
  };

  programs.kitty = {
    enable = true;
    shellIntegration.enableZshIntegration = true;
    settings = {
      window_padding_width = 2;
    };
  };

  # electron app hint
  home.sessionVariables.NIXOS_OZONE_WL = "1";

  xdg.portal = {
    enable = true;
    extraPortals = [pkgs.xdg-desktop-portal-hyprland];
    configPackages = [pkgs.hyprland];
    config = {};
  };

  home.packages = with pkgs; [
    brightnessctl
    playerctl
    pavucontrol
    hyprsunset
    hyprpolkitagent
    grimblast
  ];

  programs.rofi = {
    enable = true;
    package = pkgs.rofi-wayland;
  };

  # prefer dark mode for GTK
  dconf.settings = {
    "org/gnome/desktop/interface" = {
      color-scheme = "prefer-dark";
    };
  };
  gtk = {
    enable = true;
    gtk3.extraConfig = {
      gtk-application-prefer-dark-theme = true;
    };
    gtk4.extraConfig = {
      gtk-application-prefer-dark-theme = true;
    };
  };

  services.mako = {
    enable = true;

    inherit borderRadius borderSize;

    padding = "10";
  };

  services.hyprpaper = {
    enable = true;
    settings = {
      preload = [];
      wallpaper = [];
    };
  };

  wayland.windowManager.hyprland = {
    enable = true;
    xwayland.enable = true;

    settings = {
      "$mod" = "SUPER";
      "$term" = "kitty";
      "$menu" = "rofi -show drun";
      "$scshot" = "grimblast --freeze copy area";

      monitor = [
        "eDP-1, 2880x1920@120, 0x0, 1.875"
      ];

      exec-once = [
        "systemctl start --user hyprpolkitagent.service"
      ];

      bind =
        [
          "$mod SHIFT, Y, exit,"

          "$mod SHIFT, Return, exec, $term"
          "$mod, P, exec, $menu"
          ", Print, exec, $scshot"

          "$mod, W, killactive,"
          "$mod, Return, togglefloating,"
          "$mod, left, movefocus, l"
          "$mod, right, movefocus, r"
          "$mod, up, movefocus, u"
          "$mod, down, movefocus, d"
          "$mod SHIFT, left, resizeactive, -30 0"
          "$mod SHIFT, right, resizeactive, 30 0"
          "$mod SHIFT, up, resizeactive, 0 -30"
          "$mod SHIFT, down, resizeactive, 0 30"
        ]
        ++ (lib.concatLists (lib.genList (i: let
            ws = i + 1;
          in [
            "$mod, code:1${toString i}, workspace, ${toString ws}"
            "$mod SHIFT, code:1${toString i}, movetoworkspace, ${toString ws}"
          ])
          9));
      bindm = [
        "$mod, mouse:272, movewindow"
        "$mod, mouse:273, resizewindow"
      ];

      bindel = [
        ",XF86AudioRaiseVolume, exec, wpctl set-volume -l 1 @DEFAULT_AUDIO_SINK@ 5%+"
        ",XF86AudioLowerVolume, exec, wpctl set-volume @DEFAULT_AUDIO_SINK@ 5%-"
        ",XF86AudioMute, exec, wpctl set-mute @DEFAULT_AUDIO_SINK@ toggle"
        ",XF86MonBrightnessUp, exec, brightnessctl s 10%+"
        ",XF86MonBrightnessDown, exec, brightnessctl s 10%-"
      ];
      bindl = [
        ", XF86AudioNext, exec, playerctl next"
        ", XF86AudioPause, exec, playerctl play-pause"
        ", XF86AudioPlay, exec, playerctl play-pause"
        ", XF86AudioPrev, exec, playerctl previous"
      ];

      windowrulev2 = [
        "suppressevent maximize, class:.*"
        "float, title:.*"
        "float, initialTitle:.*(Open Files).*"
        "nofocus,class:^$,title:^$,xwayland:1,floating:1,fullscreen:0,pinned:0"
      ];

      misc = {
        disable_hyprland_logo = true;
        disable_splash_rendering = true;
      };

      general = {
        layout = "dwindle";
        border_size = borderSize;

        "col.active_border" = "$lavender";
        "col.inactive_border" = "$surface0";
      };

      decoration = {
        rounding = borderRadius;
        shadow = {
          enabled = true;
          range = 4;
          render_power = 3;
          color = "rgba(1a1a1aee)";
        };
        blur = {
          enabled = true;
          size = 3;
          passes = 1;
          vibrancy = 0.1696;
        };
      };

      dwindle = {
        pseudotile = true;
        preserve_split = true;
      };
    };
  };
}
